import pytest

from gcs_migration.models import (
    GuestCollection,
    MappedCollection,
    MigrationPlan,
    S3GuestCollection,
    S3MappedCollection,
    StorageGateway,
)
from gcs_migration.parsers import GCSConfig, GridFTPOptionParser


@pytest.fixture
def migration_plan(
    gcs_config: GCSConfig,
    gridftp_config_parser: GridFTPOptionParser,
    mapped_collection: MappedCollection,
    guest_collection_unresolved_credential: GuestCollection,
    storage_gateway: StorageGateway,
    connector: str,
) -> MigrationPlan:
    migration_plan = MigrationPlan()
    migration_plan.gcs_config = gcs_config
    migration_plan.gridftp_config = gridftp_config_parser
    migration_plan.mapped_collection = mapped_collection
    migration_plan.add_guest_collection(guest_collection_unresolved_credential)
    migration_plan.storage_gateway = storage_gateway
    assert guest_collection_unresolved_credential.credential is not None
    migration_plan.credentials = [guest_collection_unresolved_credential.credential]
    return migration_plan


@pytest.fixture(
    params=[
        "blackpearl",
        "file",
        "s3",
    ]
)
def connector(request) -> str:
    return request.param


@pytest.fixture
def migration_plan_cmd_create(
    gcs_config: GCSConfig,
    gridftp_config_parser: GridFTPOptionParser,
    mapped_collection_cmd_create: MappedCollection,
    guest_collection_unresolved_credential: GuestCollection,
    storage_gateway_cmd_create: StorageGateway,
    connector: str,
) -> MigrationPlan:
    migration_plan = MigrationPlan()
    migration_plan.gcs_config = gcs_config
    migration_plan.gridftp_config = gridftp_config_parser
    migration_plan.mapped_collection = mapped_collection_cmd_create
    migration_plan.add_guest_collection(guest_collection_unresolved_credential)
    migration_plan.storage_gateway = storage_gateway_cmd_create
    assert guest_collection_unresolved_credential.credential is not None
    migration_plan.credentials = [guest_collection_unresolved_credential.credential]
    return migration_plan


@pytest.fixture
def migration_plan_s3(
    gcs_config: GCSConfig,
    gridftp_config_parser: GridFTPOptionParser,
    s3_mapped_collection: S3MappedCollection,
    s3_guest_collection: S3GuestCollection,
    s3_storage_gateway: StorageGateway,
) -> MigrationPlan:
    migration_plan = MigrationPlan()
    migration_plan.gcs_config = gcs_config
    migration_plan.gridftp_config = gridftp_config_parser
    migration_plan.mapped_collection = s3_mapped_collection
    migration_plan.add_guest_collection(s3_guest_collection)
    migration_plan.storage_gateway = s3_storage_gateway
    assert s3_guest_collection.credential is not None
    migration_plan.credentials = [s3_guest_collection.credential]
    return migration_plan
